@@ -18,18 +18,31 @@
 #include <stdlib.h>
 #include <glib.h>
 #include <gconf/gconf-client.h>
-#include <gtk-app.h>
+#include <gtk-tw.h>
 #include <glib/gi18n.h>
 
 gint
 main(gint argc, gchar *argv[])
 {
+	gchar *dictionary = NULL, *text = NULL;
 	bindtextdomain(PACKAGE, LOCALEDIR);
 	bind_textdomain_codeset(PACKAGE, "UTF-8");
 	textdomain(PACKAGE);
 	gtk_init(&argc, &argv);
 	gconf_init(argc, argv, NULL);
-	gtk_app_new(_("GTW"));
+	switch(argc)
+	{
+		case 2:
+			text = argv[1];
+		break;
+		case 3:
+			dictionary = argv[1];
+			text = argv[2];
+		break;
+		default:
+		break;
+	}
+	gtk_tw_new(dictionary, text);
 	gtk_main();
 	return EXIT_SUCCESS;
 }
